def setup_model():

    set_seed(424242)

    title = input("Enter the title of your article: ")
    print("\n")
    prompt = input("Enter the promt you wish for the article: ")
    formatted_prompt = prompt.format()

    MAX_LENGTH = int(input("Enter the maximum number of words you'd like in your content: "))
    print("\n")

    input_ids = tokenizer(formatted_prompt, return_tensors="pt").to(0)


def generate_text():
    print("\n")
    sample = model.generate(**input_ids, max_length=length,  num_beams = 2, num_beam_groups = 2, top_k=1, temperature=1.5, repetition_penalty = 3.0, diversity_penalty = 1.2)
    str(tokenizer.decode(sample[0]))
    # print(tokenizer.decode(sample[0], truncate_before_pattern=[r"\n\n^#", "^'''", "\n\n\n"]))

def run():
    setup_model()
  
    generate_text()


    filename = title + ".txt"



    with open(filename, "w") as f:
      f.close()

    location = '/content/'+title+'.txt'

    with open(filename, "a") as f:

      if os.stat(location).st_size == 0:
        print('File is empty')
        f.write('\n'+str(tokenizer.decode(sample[0])).replace('</s>', ''))
      else:
        print('File is not empty')
        print("\n")
        f.write('\n'+str(tokenizer.decode(sample[0])).replace('</s>', ''))
      f.close()

    print("\n\n")
    print(str(tokenizer.decode(sample[0])).replace('</s>', ''))


    files.download(location)




def load_model():
    from transformers import AutoModelForCausalLM, AutoTokenizer, set_seed
    import torch
    import os
    from google.colab import files

  torch.set_default_tensor_type(torch.cuda.FloatTensor)
  the_model_repo_address = str(input("Enter the address for Model Repo from Huggingface: "))
  print("\n")

model = AutoModelForCausalLM.from_pretrained(the_model_repo_address, use_cache=True)
tokenizer = AutoTokenizer.from_pretrained(the_model_repo_address)



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '1.2'
DESCRIPTION = 'for generating contents on the basis of provided prompts and input lengths'
LONG_DESCRIPTION = 'A package that uses pretrained abstractive models from huggingface models for text generation and gives a rather simple way to have the result downloaded into the local directory directly from google colab'

# Setting up
setup(
    name="prikarsartamGeneratesContents",
    version=VERSION,
    author="Pritam Darkar <prikarsartam.ml>",
    author_email="<prikarsartam@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['transformers', 'torch', 'os', 'google-colab'],
    keywords=['large language model', 'text generation', 'pretrained content creation', 'AutoCausalModelforBloomLM', 'Natural Language Processing', 'python'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
